## cdist-type__apt_ppa(7)

### Steven Armstrong

`<steven-cdist--@--armstrong.cc>`

## 1. NAME

cdist-type__apt_ppa - Manage ppa repositories

## 2. DESCRIPTION

This cdist type allows manage ubuntu ppa repositories.

## 3. REQUIRED PARAMETERS

state
  The state the ppa should be in, either present or absent. Defaults to present

## 4. OPTIONAL PARAMETERS

None.

## 5. EXAMPLES

    # Enable a ppa repository
    __apt_ppa ppa:sans-intern/missing-bits
    # same as
    __apt_ppa ppa:sans-intern/missing-bits --state present

    # Disable a ppa repository
    __apt_ppa ppa:sans-intern/missing-bits --state absent

## 6. SEE ALSO

- cdist-type(7)

## 7. COPYING

Copyright (C) 2011-2014 Steven Armstrong. Free use of this software is granted under the terms of the GNU General Public License version 3 (GPLv3).